@@ -1,4 +1,4 @@
-__version__ = "0.6.11"
+__version__ = "0.6.12"
 
 from .core import (
     magicclass,
@@ -20,15 +20,24 @@ from .wrappers import (
     confirm,
     nogui,
     mark_preview,
+    impl_preview,
     mark_on_calling,
     mark_on_called,
 )
 
-from .fields import field, vfield, widget_property, FieldGroup, HasFields, dataclass_gui
+from .fields import (
+    field,
+    vfield,
+    widget_property,
+    magicproperty,
+    FieldGroup,
+    HasFields,
+    dataclass_gui,
+)
 from ._gui._base import defaults, MagicTemplate, PopUpMode
 from ._gui.keybinding import Key
 from ._gui._icon import Icon
-from . import widgets, utils, types, functools
+from . import widgets, utils, types, functools, logging
 
 from magicgui import *
 
@@ -49,11 +58,13 @@ __all__ = [
     "confirm",
     "nogui",
     "mark_preview",
+    "impl_preview",
     "mark_on_calling",
     "mark_on_called",
     "field",
     "vfield",
     "widget_property",
+    "magicproperty",
     "FieldGroup",
     "HasFields",
     "dataclass_gui",
