@@ -218,6 +218,8 @@ def check_override(cls: type):
         )
 
 
+_ANCESTORS: dict[tuple[int, int], MagicTemplate] = {}
+
 _T = TypeVar("_T", bound="MagicTemplate")
 _F = TypeVar("_F", bound=Callable)
 
@@ -358,9 +360,10 @@ class MagicTemplate(MutableSequence[_W], metaclass=_MagicTemplateMeta):
 
         return dock
 
-    def find_ancestor(self, ancestor: type[_T]) -> _T:
+    def find_ancestor(self, ancestor: type[_T], cache: bool = False) -> _T:
         """
         Find magic class ancestor whose type matches the input.
+
         This method is useful when a child widget class is defined outside a magic
         class while it needs access to its parent.
 
@@ -368,12 +371,18 @@ class MagicTemplate(MutableSequence[_W], metaclass=_MagicTemplateMeta):
         ----------
         ancestor : type of MagicTemplate
             Type of ancestor to search for.
+        cache : bool, default is False
+            If true, the result will be cached. Caching is not safe if the widget is
+            going to be used as a child of other widgets.
 
         Returns
         -------
         MagicTemplate
             Magic class object if found.
         """
+        if cache and (anc := _ANCESTORS.get((id(self), id(ancestor)), None)):
+            return anc
+
         if not isinstance(ancestor, type):
             raise TypeError(
                 "The first argument of 'find_ancestor' must be a type but got "
@@ -388,6 +397,8 @@ class MagicTemplate(MutableSequence[_W], metaclass=_MagicTemplateMeta):
                     f"Magic class {ancestor.__name__} not found. {ancestor.__name__} "
                     f"is not an ancestor of {self.__class__.__name__}"
                 )
+        if cache:
+            _ANCESTORS[(id(self), id(ancestor))] = current_self
         return current_self
 
     def objectName(self) -> str:
@@ -546,6 +557,7 @@ class MagicTemplate(MutableSequence[_W], metaclass=_MagicTemplateMeta):
                     else:
                         del child_instance[index - 1]
                         child_instance._fast_insert(index, widget)
+                    widget.visible = True
 
                 else:
                     widget.visible = copy
@@ -1011,10 +1023,12 @@ def _build_mgui(widget_: Action | PushButtonPlus, func: Callable, parent: BaseGu
         mgui = FunctionGuiPlus(
             func, call_button, layout=layout, labels=labels, auto_call=auto_call
         )
-        preview = opt.get("preview", None)
-        if preview is not None:
-            btn_text, previewer = preview
-            mgui.append_preview(previewer.__get__(parent), btn_text)
+        preview_setting = opt.get("preview", None)
+        if preview_setting is not None:
+            btn_text, is_auto_call, previewer = preview_setting
+            mgui.append_preview(
+                previewer.__get__(parent), btn_text, auto_call=is_auto_call
+            )
 
     except Exception as e:
         msg = (
@@ -1096,7 +1110,7 @@ def convert_attributes(cls: type[_T], hide: tuple[type, ...]) -> dict[str, Any]:
         New namespace.
     """
     _dict: dict[str, Callable] = {}
-    _pass_type = (property, classmethod, staticmethod, type, Widget)
+    _pass_type = (property, classmethod, staticmethod, type, Widget, MagicField)
     mro = [c for c in cls.__mro__ if c not in hide]
     for subcls in reversed(mro):
         for name, obj in subcls.__dict__.items():
