@@ -8,7 +8,8 @@ from vispy.visuals import (
     IsosurfaceVisual,
     MeshVisual,
     LineVisual,
-    BoxVisual,
+    MarkersVisual,
+    ArrowVisual,
 )
 from vispy.visuals import transforms as tr
 from vispy.visuals.filters import WireframeFilter
@@ -19,6 +20,18 @@ from ...widgets import FloatRangeSlider
 from ...fields import HasFields, vfield
 from ...types import Color
 
+# Copied from napari/_vispy/utils/gl.py
+BLENDING_MODES = {
+    'opaque': dict(preset='opaque'),
+    'translucent': dict(preset='translucent'),
+    'translucent_no_depth': dict(
+        depth_test=False,
+        cull_face=False,
+        blend=True,
+        blend_func=('src_alpha', 'one_minus_src_alpha', 'zero', 'one'),
+    ),
+    'additive': dict(preset='additive'),
+}
 
 class Image(LayerItem, HasFields):
     RENDERINGS = [
@@ -118,6 +131,7 @@ class Image(LayerItem, HasFields):
 
     @property
     def data(self) -> np.ndarray:
+        """Image data."""
         return self._data
 
     @data.setter
@@ -133,10 +147,6 @@ class Image(LayerItem, HasFields):
         self._cache_lims()
         self._visual.update()
 
-    @property
-    def name(self) -> str:
-        return self._name
-
     def _cache_lims(self):
         self._lims = np.min(self._data), np.max(self._data)
         self.widgets.contrast_limits.min = self._lims[0]
@@ -222,10 +232,6 @@ class _SurfaceBase(LayerItem):
         self.shading = shading
         self._name = name
 
-    @property
-    def name(self) -> str:
-        return self._name
-
     def _create_visual(self, data):
         raise NotImplementedError()
 
@@ -422,8 +428,9 @@ class Curve3D(LayerItem, HasFields):
         self,
         data,
         viewbox: ViewBox,
-        color=None,
-        width=1.0,
+        color: Color = None,
+        width: float = 1.0,
+        blending: str = "translucent",
         name: str | None = None,
     ):
         super().__init__()
@@ -434,6 +441,7 @@ class Curve3D(LayerItem, HasFields):
             pos=data, color=color, width=width, parent=self._viewbox.scene
         )
         self.data = data
+        self.blending = blending
 
     @property
     def data(self) -> np.ndarray:
@@ -450,19 +458,233 @@ class Curve3D(LayerItem, HasFields):
         maxs = np.max(self.data, axis=0)
         return mins, maxs
 
-    @property
-    def name(self) -> str:
-        return self._name
-
     # fmt: off
     color = vfield(Color)
-    width = vfield(float, widget_type=FloatSlider, options={"min": 0.5, "max": 10.0, "value": 1.0})
+    width = vfield(1.0, widget_type=FloatSlider, options={"min": 0.5, "max": 10.0})
+    blending = vfield("translucent", options={"choices": BLENDING_MODES.keys()})
     # fmt: on
 
     @color.connect
     def _on_color_change(self, value):
-        self._visual.set_data(color=value)
+        return self._visual.set_data(color=value)
 
     @width.connect
     def _on_width_change(self, value):
-        self._visual.set_data(width=value)
+        return self._visual.set_data(width=value)
+    
+    @blending.connect
+    def _on_blending_change(self, value):
+        blending_kwargs = BLENDING_MODES[value]
+        self._visual.set_gl_state(**blending_kwargs)
+        self._visual.update()
+        return None
+
+
+class Points3D(LayerItem, HasFields):
+    def __init__(
+        self,
+        data,
+        viewbox: ViewBox,
+        face_color: Color | None = None,
+        edge_color: Color | None = None,
+        edge_width: float = 0.0,
+        size: float = 1.0,
+        blending: str = "translucent",
+        spherical: bool = True,
+        name: str | None = None,
+    ):
+        super().__init__()
+        self._name = name
+        self._viewbox = viewbox
+        self._visual: MarkersVisual = visuals.Markers(
+            scaling=True, parent=self._viewbox.scene, spherical=True
+        )
+        self.data = data[:, ::-1]
+        self.face_color = face_color
+        self.edge_color = edge_color
+        self.edge_width = edge_width
+        self.size = size
+        self.blending = blending
+        self.spherical = spherical
+
+    @property
+    def data(self) -> np.ndarray:
+        return self._data
+
+    @data.setter
+    def data(self, value) -> None:
+        self._visual.set_data(
+            pos=value,
+            face_color=self.face_color,
+            edge_color=self.edge_color,
+            edge_width=self.edge_width,
+            size=self.size,
+            scaling=True,
+            symbol=self._visual.symbol,
+        )
+        self._data = value
+        self._visual.update()
+
+    # fmt: off
+    face_color = vfield(Color)
+    edge_color = vfield(Color)
+    edge_width = vfield(0.0, options={"min": 0.0, "max": 5.0, "step": 0.5})
+    size = vfield(5.0, options={"min": 1.0, "max": 50.0, "step": 0.5})
+    blending = vfield("translucent", options={"choices": BLENDING_MODES.keys()})
+    spherical = vfield(True)
+    # fmt: on
+
+    @face_color.connect
+    def _on_face_color_change(self, value):
+        return self._visual.set_data(
+            pos=self.data,
+            face_color=value,
+            edge_color=self.edge_color,
+            edge_width=self.edge_width,
+            size=self.size,
+            scaling=True,
+            symbol=self._visual.symbol,
+        )
+
+    @edge_color.connect
+    def _on_edge_color_change(self, value):
+        return self._visual.set_data(
+            pos=self.data,
+            face_color=self.face_color,
+            edge_color=value,
+            edge_width=self.edge_width,
+            size=self.size,
+            scaling=True,
+            symbol=self._visual.symbol,
+        )
+
+    @edge_width.connect
+    def _on_edge_width_change(self, value):
+        return self._visual.set_data(
+            pos=self.data,
+            face_color=self.face_color,
+            edge_color=self.edge_color,
+            edge_width=value,
+            size=self.size,
+            scaling=True,
+            symbol=self._visual.symbol,
+        )
+
+    @spherical.connect
+    def _on_spherical_change(self, value):
+        self._visual.spherical = value
+        self._visual.update()
+
+    @size.connect
+    def _on_size_change(self, value):
+        return self._visual.set_data(
+            pos=self.data,
+            face_color=self.face_color,
+            edge_color=self.edge_color,
+            edge_width=self.edge_width,
+            size=value,
+            scaling=True,
+            symbol=self._visual.symbol,
+        )
+    
+    @blending.connect
+    def _on_blending_change(self, value):
+        blending_kwargs = BLENDING_MODES[value]
+        self._visual.set_gl_state(**blending_kwargs)
+        self._visual.update()
+        return None
+
+    def _get_bbox(self) -> Tuple[np.ndarray, np.ndarray]:
+        mins = np.min(self.data, axis=0)
+        maxs = np.max(self.data, axis=0)
+        return mins, maxs
+
+
+class Arrows3D(LayerItem, HasFields):
+    _ARROW_TYPES = (
+        "stealth",
+        "curved",
+        "triangle_30",
+        "triangle_60",
+        "triangle_90",
+        "angle_30",
+        "angle_60",
+        "angle_90",
+        "inhibitor_round",
+    )
+
+    def __init__(
+        self,
+        data: np.ndarray,
+        viewbox: ViewBox,
+        color: Color | None = None,
+        width: float = 0.0,
+        arrow_type: str = "stealth",
+        arrow_size: float = 1.0,
+        blending: str = "translucent",
+        name: str | None = None,
+    ):
+        super().__init__()
+        self._name = name
+        self._viewbox = viewbox
+        data = data
+        self._visual: ArrowVisual = visuals.Arrow(
+            parent=self._viewbox.scene, connect="segments"
+        )
+        self.data = data[:, :, ::-1]
+        self.color = color
+        self.width = width
+        self.arrow_type = arrow_type
+        self.arrow_size = arrow_size
+        self.blending = blending
+
+    # fmt: off
+    color = vfield(Color)
+    width = vfield(0.0, widget_type=FloatSlider, options={"min": 0.0, "max": 5.0})
+    arrow_type = vfield("stealth", options={"choices": _ARROW_TYPES})
+    arrow_size = vfield(1.0, options={"min": 0.5, "max": 100})
+    blending = vfield("translucent", options={"choices": BLENDING_MODES.keys()})
+    # fmt: on
+
+    @property
+    def data(self) -> np.ndarray:
+        return self._data
+
+    @data.setter
+    def data(self, value: np.ndarray) -> None:
+        # value.shape == (N, P, 3)
+        arrows = value[:, -2:].reshape(-1, 6)
+        self._visual.set_data(pos=value, arrows=arrows)
+        self._data = value
+        self._visual.update()
+
+    @color.connect
+    def _on_color_change(self, value):
+        self._visual.arrow_color = value
+        return self._visual.set_data(color=value)
+
+    @width.connect
+    def _on_width_change(self, value):
+        return self._visual.set_data(width=value)
+
+    @arrow_type.connect
+    def _on_arrow_type_change(self, value):
+        self._visual.arrow_type = value
+        self._visual.update()
+
+    @arrow_size.connect
+    def _on_arrow_size_change(self, value):
+        self._visual.arrow_size = value
+        self._visual.update()
+
+    @blending.connect
+    def _on_blending_change(self, value):
+        blending_kwargs = BLENDING_MODES[value]
+        self._visual.set_gl_state(**blending_kwargs)
+        self._visual.update()
+        return None
+
+    def _get_bbox(self) -> Tuple[np.ndarray, np.ndarray]:
+        mins = np.min(self.data, axis=(0, 1))
+        maxs = np.max(self.data, axis=(0, 1))
+        return mins, maxs
