@@ -46,16 +46,16 @@ def _btn_text_warning():
 class _Splitter(ContainerBase):
     _qwidget: QtW.QWidget
 
-    def __init__(self, layout="vertical", scrollable: bool = False):
+    def __init__(self, layout="vertical", scrollable: bool = False, **kwargs):
         QBaseWidget.__init__(self, QtW.QWidget)
         # SetLayout is not supported for QSplitter.
         # Layout is just a dummy.
         self._splitter = QtW.QSplitter(self._qwidget)
         if layout == "horizontal":
-            self._splitter.setOrientation(Qt.Horizontal)
+            self._splitter.setOrientation(Qt.Orientation.Horizontal)
             self._layout = QtW.QHBoxLayout()
         else:
-            self._splitter.setOrientation(Qt.Vertical)
+            self._splitter.setOrientation(Qt.Orientation.Vertical)
             self._layout = QtW.QVBoxLayout()
 
         self._scroll_area = None
@@ -79,7 +79,7 @@ class _Splitter(ContainerBase):
 class _ToolBox(ContainerBase):
     _qwidget: QtW.QToolBox
 
-    def __init__(self, layout="vertical", scrollable: bool = False):
+    def __init__(self, layout="vertical", scrollable: bool = False, **kwargs):
         QBaseWidget.__init__(self, QtW.QToolBox)
 
         if layout == "horizontal":
@@ -102,7 +102,7 @@ class _ToolBox(ContainerBase):
 
 
 class _Tab(ContainerBase):
-    def __init__(self, layout="vertical", scrollable: bool = False):
+    def __init__(self, layout="vertical", scrollable: bool = False, **kwargs):
         QBaseWidget.__init__(self, QtW.QWidget)
 
         if layout == "horizontal":
@@ -130,7 +130,7 @@ class _Tab(ContainerBase):
 
 
 class _Stack(ContainerBase):
-    def __init__(self, layout="vertical", scrollable: bool = False):
+    def __init__(self, layout="vertical", scrollable: bool = False, **kwargs):
         QBaseWidget.__init__(self, QtW.QWidget)
 
         if layout == "horizontal":
@@ -154,7 +154,7 @@ class _Stack(ContainerBase):
 
 
 class _ScrollableContainer(ContainerBase):
-    def __init__(self, layout="vertical", scrollable: bool = False):
+    def __init__(self, layout="vertical", scrollable: bool = False, **kwargs):
         QBaseWidget.__init__(self, QtW.QWidget)
         self._scroll_area = QtW.QScrollArea(self._qwidget)
         if layout == "horizontal":
@@ -183,7 +183,7 @@ class _WheelDisabledScrollArea(QtW.QScrollArea):
 
 
 class _DraggableContainer(ContainerBase):
-    def __init__(self, layout="vertical", scrollable: bool = False):
+    def __init__(self, layout="vertical", scrollable: bool = False, **kwargs):
         QBaseWidget.__init__(self, QtW.QWidget)
         self._scroll_area = _WheelDisabledScrollArea(self._qwidget)
         if layout == "horizontal":
@@ -215,7 +215,7 @@ class _DraggableContainer(ContainerBase):
 
 
 class _ButtonContainer(ContainerBase):
-    def __init__(self, layout="vertical", text="", scrollable: bool = False):
+    def __init__(self, layout="vertical", text="", scrollable: bool = False, **kwargs):
         QBaseWidget.__init__(self, QtW.QWidget)
         if layout == "horizontal":
             self._layout: QtW.QLayout = QtW.QHBoxLayout()
@@ -258,7 +258,7 @@ class _QCollapsible(QtW.QWidget):
 class _Collapsibles(ContainerBase):
     _setting: dict[str, Any]
 
-    def __init__(self, layout="vertical", text="", scrollable: bool = False):
+    def __init__(self, layout="vertical", text="", scrollable: bool = False, **kwargs):
         QBaseWidget.__init__(self, QtW.QWidget)
         if layout == "horizontal":
             self._layout: QtW.QLayout = QtW.QHBoxLayout()
@@ -349,7 +349,7 @@ class _QListWidget(QtW.QListWidget):
 
 
 class _ListContainer(ContainerBase):
-    def __init__(self, layout="vertical", scrollable: bool = False):
+    def __init__(self, layout="vertical", scrollable: bool = False, **kwargs):
         QBaseWidget.__init__(self, QtW.QWidget)
         self._listwidget = _QListWidget(self._qwidget)
         if layout == "horizontal":
@@ -361,9 +361,9 @@ class _ListContainer(ContainerBase):
         self._qwidget.setLayout(self._layout)
 
         if layout == "horizontal":
-            self._listwidget.setFlow(QtW.QListView.LeftToRight)
+            self._listwidget.setFlow(QtW.QListView.Flow.LeftToRight)
         else:
-            self._listwidget.setFlow(QtW.QListView.TopToBottom)
+            self._listwidget.setFlow(QtW.QListView.Flow.TopToBottom)
 
     def _mgui_insert_widget(self, position: int, widget: Widget):
         item = QtW.QListWidgetItem(self._listwidget)
@@ -389,10 +389,12 @@ class _SubWindowsContainer(ContainerBase):
     # The close button in QMdiArea completely deletes the sub window widget. This accident
     # can be avoided by defining a custom window flag.
     _NoCloseButtonFlag = (
-        Qt.CustomizeWindowHint | Qt.WindowTitleHint | Qt.WindowMinMaxButtonsHint
+        Qt.WindowType.CustomizeWindowHint
+        | Qt.WindowType.WindowTitleHint
+        | Qt.WindowType.WindowMinMaxButtonsHint
     )
 
-    def __init__(self, layout="vertical", scrollable: bool = False):
+    def __init__(self, layout="vertical", scrollable: bool = False, **kwargs):
         QBaseWidget.__init__(self, QtW.QWidget)
         self._mdiarea = QtW.QMdiArea(self._qwidget)
         if layout == "horizontal":
@@ -413,7 +415,7 @@ class _SubWindowsContainer(ContainerBase):
 
 
 class _GroupBoxContainer(ContainerBase):
-    def __init__(self, layout="vertical", scrollable: bool = False):
+    def __init__(self, layout="vertical", scrollable: bool = False, **kwargs):
         QBaseWidget.__init__(self, QtW.QWidget)
 
         # To precisely control margins, _layout should not be set to the QGroupBox widget.
@@ -437,7 +439,7 @@ class _GroupBoxContainer(ContainerBase):
 
 
 class _FrameContainer(_GroupBoxContainer):
-    def __init__(self, layout="vertical", scrollable: bool = False):
+    def __init__(self, layout="vertical", scrollable: bool = False, **kwargs):
         super().__init__(layout=layout)
         self._groupbox.setTitle("")
 
